.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1684: * @file leo.external.concurrent.rst
.. @@language rest
concurrent Package
==================

:mod:`concurrent` Package
-------------------------

.. automodule:: leo.external.concurrent
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    leo.external.concurrent.futures

.. @-leo
